@@ -9,7 +9,6 @@ import tempfile
 import textwrap
 from collections import defaultdict, deque, UserDict
 from dataclasses import dataclass
-from functools import partial
 from itertools import chain
 
 from pkgcheck import reporters, scan
@@ -17,7 +16,6 @@ from pkgcore.ebuild.atom import MalformedAtom
 from pkgcore.ebuild.atom import atom as atom_cls
 from pkgcore.ebuild.repository import UnconfiguredTree
 from pkgcore.operations import observer as observer_mod
-from pkgcore.repository import errors as repo_errors
 from pkgcore.restrictions import packages
 from snakeoil.cli import arghparse
 from snakeoil.cli.input import userquery
@@ -108,8 +106,7 @@ msg_actions.add_argument(
     help='specify commit message',
     docs="""
         Use a given message as the commit message. If multiple -m options are
-        specified, their values are concatenated as separate paragraphs with
-        line wrapping at 100 characters.
+        specified, their values are concatenated as separate paragraphs.
 
         Note that the first value will be used for the commit summary and if
         it's empty then a generated summary will be used if available.
@@ -139,8 +136,18 @@ class _HistoricalRepo(UnconfiguredTree):
 
     def __init__(self, repo, *args, **kwargs):
         self.__parent_repo = repo
+        self.__tmpdir = tempfile.TemporaryDirectory()
         self.__created = False
-        super().__init__(*args, **kwargs)
+        repo_dir = self.__tmpdir.name
+
+        # set up some basic repo files so pkgcore doesn't complain
+        os.makedirs(pjoin(repo_dir, 'metadata'))
+        with open(pjoin(repo_dir, 'metadata', 'layout.conf'), 'w') as f:
+            f.write(f"masters = {' '.join(x.repo_id for x in repo.trees)}\n")
+        os.makedirs(pjoin(repo_dir, 'profiles'))
+        with open(pjoin(repo_dir, 'profiles', 'repo_name'), 'w') as f:
+            f.write(f'{repo.repo_id}-old\n')
+        super().__init__(repo_dir)
 
     def add_pkgs(self, pkgs):
         """Update the repo with a given sequence of packages."""
@@ -194,24 +201,7 @@ class ChangeSummary:
     @jit_attr
     def old_repo(self):
         """Create a repository of historical packages removed from git."""
-        tmpdir = tempfile.TemporaryDirectory()
-        atexit.register(tmpdir.cleanup)
-        repo_dir = tmpdir.name
-
-        # set up some basic repo files so pkgcore doesn't complain
-        os.makedirs(pjoin(repo_dir, 'metadata'))
-        with open(pjoin(repo_dir, 'metadata', 'layout.conf'), 'w') as f:
-            f.write(f'masters = {self.repo.repo_id}\n')
-        os.makedirs(pjoin(repo_dir, 'profiles'))
-        with open(pjoin(repo_dir, 'profiles', 'repo_name'), 'w') as f:
-            f.write(f'{self.repo.repo_id}-old\n')
-
-        repo_cls = partial(_HistoricalRepo, self.repo)
-        try:
-            return self.options.domain.add_repo(
-                repo_dir, self.options.config, tree_cls=repo_cls)
-        except repo_errors.RepoError:
-            pass
+        return _HistoricalRepo(self.repo)
 
     def generate(self):
         """Generate summaries for the package changes."""
@@ -234,10 +224,6 @@ class MetadataSummary(ChangeSummary):
     @change('M')
     def modify(self):
         """Generate summaries for modify actions."""
-        if self.old_repo is None:
-            # error initializing historical repo
-            return
-
         atom = next(iter(self.changes))
         self.old_repo.add_pkgs([atom])
         try:
@@ -247,14 +233,14 @@ class MetadataSummary(ChangeSummary):
             return
 
         if old_pkg.maintainers != new_pkg.maintainers:
-            new = set(new_pkg.maintainers)
-            old = set(old_pkg.maintainers)
+            new = {x.email for x in new_pkg.maintainers}
+            old = {x.email for x in old_pkg.maintainers}
             p = git.run('config', 'user.email', stdout=subprocess.PIPE)
             git_email = p.stdout.strip()
-            if git_email in list(new - old):
-                return 'add myself to maintainers'
-            if git_email in list(old - new):
-                return 'drop myself from maintainers'
+            if git_email in new - old:
+                return 'add myself as a maintainer'
+            if git_email in old - new:
+                return 'drop myself as a maintainer'
             return 'update maintainers'
         elif old_pkg.stabilize_allarches != new_pkg.stabilize_allarches:
             status = 'mark' if new_pkg.stabilize_allarches else 'drop'
@@ -308,13 +294,12 @@ class PkgSummary(ChangeSummary):
             msg = f"add {', '.join(self.versions)}"
             if len(self.versions) == 1 or len(msg) <= 50:
                 return msg
-            else:
-                return 'add versions'
+            return 'add versions'
         elif len(self.changes) == 1:
             # adding a new revbump
             atom = next(iter(self.changes))
             # assume revbump was based on the previous version
-            pkgs = [x for x in self.repo.match(atom.unversioned_atom) if x <= atom]
+            pkgs = sorted(x for x in self.repo.match(atom.unversioned_atom) if x <= atom)
             try:
                 old_pkg, new_pkg = pkgs[-2:]
             except ValueError:
@@ -331,8 +316,7 @@ class PkgSummary(ChangeSummary):
             msg = f"drop {', '.join(self.versions)}"
             if len(self.versions) == 1 or len(msg) <= 50:
                 return msg
-            else:
-                return 'drop versions'
+            return 'drop versions'
         return 'treeclean'
 
     @change('R')
@@ -347,10 +331,6 @@ class PkgSummary(ChangeSummary):
     def modify(self):
         """Generate summaries for modify actions."""
         if len(self.changes) == 1:
-            if self.old_repo is None:
-                # error initializing historical repo
-                return
-
             atom = next(iter(self.changes))
             self.old_repo.add_pkgs([atom])
             try:
@@ -367,29 +347,21 @@ class PkgSummary(ChangeSummary):
                 added = new_keywords - old_keywords
                 removed = old_keywords - new_keywords
                 if removed == {f'~{x}' for x in added}:
-                    msg = f"stabilize {atom.fullver}: {', '.join(sorted(added))}"
-                    if len(msg) <= 50:
-                        return msg
-                    else:
-                        return f'stabilize {atom.fullver}'
+                    action = f'stabilize {atom.fullver}'
+                    msg = f"{action} for {', '.join(sorted(added))}"
                 elif not removed and all(x.startswith('~') for x in added):
-                    msg = f"keyword {atom.fullver}: {', '.join(sorted(added))}"
-                    if len(msg) <= 50:
-                        return msg
-                    else:
-                        return f'keyword {atom.fullver}'
+                    action = f'keyword {atom.fullver}'
+                    msg = f"{action} for {', '.join(sorted(added))}"
                 elif removed == {x.lstrip('~') for x in added}:
-                    msg = f"revert {atom.fullver} keywords: {', '.join(sorted(added))}"
-                    if len(msg) <= 50:
-                        return msg
-                    else:
-                        return f'revert {atom.fullver} keywords'
+                    action = f'destabilize {atom.fullver}'
+                    msg = f"{action} for {', '.join(sorted(added))}"
                 elif not added:
-                    msg = f"remove {atom.fullver} keywords: {', '.join(sorted(removed))}"
-                    if len(msg) <= 50:
-                        return msg
-                    else:
-                        return f'remove {atom.fullver} keywords'
+                    action = f'unkeyword {atom.fullver}'
+                    msg = f"{action} for {', '.join(sorted(removed))}"
+
+                if len(msg) <= 50:
+                    return msg
+                return action
 
 
 class GitChanges(UserDict):
@@ -436,8 +408,7 @@ class GitChanges(UserDict):
                         return f'{common_path}: '
                     elif common_path:
                         return f'{common_path}/*: '
-                    else:
-                        return '*/*: '
+                    return '*/*: '
                 elif common_path:
                     return f'{common_path}: '
 
@@ -472,9 +443,8 @@ class Change:
         if os.sep in self.path:
             # use change path's parent directory
             return f'{os.path.dirname(self.path)}: '
-        else:
-            # use repo root file name
-            return f'{self.path}: '
+        # use repo root file name
+        return f'{self.path}: '
 
 
 @dataclass(frozen=True)
