@@ -1,6 +1,7 @@
 import pytest
 from pkgdev.cli import Tool
 from pkgdev.scripts import pkgdev
+from snakeoil.cli import arghparse
 
 pytest_plugins = ['pkgcore']
 
@@ -16,3 +17,9 @@ def tool():
 def parser():
     """Return a shallow copy of the main pkgdev argparser."""
     return pkgdev.argparser.copy()
+
+
+@pytest.fixture
+def namespace():
+    """Return an arghparse Namespace object."""
+    return arghparse.Namespace()
