@@ -388,7 +388,8 @@ class TestPkgdevCommit:
         git_repo.add_all('cat/pkg-0')
 
         def commit():
-            with patch('sys.argv', self.args + ['-a']), \
+            with os_environ(GIT_EDITOR="sed -i '1s/$/commit/'"), \
+                    patch('sys.argv', self.args + ['-a']), \
                     pytest.raises(SystemExit) as excinfo, \
                     chdir(git_repo.path):
                 self.script()
@@ -409,7 +410,42 @@ class TestPkgdevCommit:
         # multiple additions
         repo.create_ebuild('cat/pkg-2')
         repo.create_ebuild('cat/pkg-3')
-        assert commit() == 'cat/pkg: add 2, 3'
+        repo.create_ebuild('cat/pkg-4', eapi=6)
+        assert commit() == 'cat/pkg: add 2, 3, 4'
+
+        # revbump updating EAPI
+        repo.create_ebuild('cat/pkg-4-r1', eapi=7)
+        assert commit() == 'cat/pkg: update EAPI 6 -> 7'
+
+        # single rename with no revisions
+        git_repo.move(
+            pjoin(git_repo.path, 'cat/pkg/pkg-4.ebuild'),
+            pjoin(git_repo.path, 'cat/pkg/pkg-5.ebuild'),
+            commit=False
+        )
+        assert commit() == 'cat/pkg: add 5, drop 4'
+
+        # keyword version
+        repo.create_ebuild('cat/pkg-6')
+        git_repo.add_all('cat/pkg-6')
+        repo.create_ebuild('cat/pkg-6', keywords=['~amd64'])
+        assert commit() == 'cat/pkg: keyword 6 for ~amd64'
+
+        # stabilize version
+        repo.create_ebuild('cat/pkg-6', keywords=['amd64'])
+        assert commit() == 'cat/pkg: stabilize 6 for amd64'
+
+        # destabilize version
+        repo.create_ebuild('cat/pkg-6', keywords=['~amd64'])
+        assert commit() == 'cat/pkg: destabilize 6 for ~amd64'
+
+        # unkeyword version
+        repo.create_ebuild('cat/pkg-6', eapi='6')
+        assert commit() == 'cat/pkg: unkeyword 6 for ~amd64'
+
+        # bump EAPI
+        repo.create_ebuild('cat/pkg-6', eapi='7')
+        assert commit() == 'cat/pkg: update EAPI 6 -> 7'
 
         # large number of additions in a single commit
         for v in range(10000, 10010):
@@ -428,7 +464,9 @@ class TestPkgdevCommit:
         os.remove(pjoin(git_repo.path, 'cat/pkg/Manifest'))
         assert commit() == 'cat/pkg: update Manifest'
 
-        # single removal
+        # single removals
+        os.remove(pjoin(git_repo.path, 'cat/pkg/pkg-4-r1.ebuild'))
+        assert commit() == 'cat/pkg: drop 4-r1'
         os.remove(pjoin(git_repo.path, 'cat/pkg/pkg-3.ebuild'))
         assert commit() == 'cat/pkg: drop 3'
 
